"use strict";

const GAMEDEV_THEMES = [
    {
        title: "Dessin et création 2D",
        class: "crea2d",
        details: [
            "Création de décors et de personnages",
            "Dessin sur ordinateur, pixel art, vectoriel",
            "Animations 2D",
        ],
    },
    {
        title: "Musique et sons",
        class: "sound",
        details: ["Logiciels de son et synthétiseurs", "Composition", "Prise de son", "Mixage"],
    },
    {
        title: "Écriture",
        class: "write",
        details: [
            "Écrire une histoire, construire une narration",
            "Imaginer des mondes et des personnages",
        ],
    },
    {
        title: "Conception",
        class: "conception",
        comment: "",
        details: [
            "Concevoir les différents éléments qui composent le jeu",
            "Développer les mécanismes de gameplay",
        ],
    },
    {
        title: "Programmation",
        class: "coding",
        comment: "",
        details: [
            "Apprendre pas à pas à coder avec différents langages de programmation",
            "Découvrir les bases du web en créant des mini-jeux en lignes",
        ],
    },
    {
        title: "Mathématiques",
        class: "math",
        comment:
            "<em>Créer un jeu vidéo c'est l'occasion de découvrir plein de sujets en maths et en physique tout en s'amusant !</em>",
        details: [
            "Algorithmie",
            "Logique (algèbre booléen)",
            "Géométrie",
            "Trigonométrie",
            "Algèbre linéaire",
            "Repères 2D / 3D",
            "Vecteurs 2D / 3D",
            "Newton",
            "...",
        ],
    },
    {
        title: "Travail d'équipe",
        class: "team",
        comment: `
            <em>
                Faire son jeu tout seul c'est bien mais ça peut être long !
                <br>Créer des jeux c'est aussi l'occasion de se mettre à plusieurs pour tirer le meilleur parti des différents talents de chacun.
            </em>`,
        details: [],
    },
    {
        title: "Logiciels libres, GNU/Linux",
        class: "linux",
        comment:
            "<em>Nous utilisons essentiellement des logiciels libres sur Linux.<br>C'est donc une bonne occasion de découvrir et démystifier tout ça en douceur !</em>",
        details: [],
    },
];

class GameStudioClub {
    render() {
        return {
            tag: "section",
            contents: [
                {
                    tag: "div",
                    class: "title-banner",
                    id: "game-studio-club", // anchor id
                    contents: [{ tag: "h2", contents: "Game Studio Club" }],
                },
                {
                    tag: "div",
                    class: "section-contents",
                    contents: [
                        {
                            tag: "div",
                            class: "full-row",
                            contents: [
                                { tag: "h3", contents: "Apprendre à créer un jeu vidéo de A à Z" },
                                {
                                    tag: "strong",
                                    contents:
                                        "La création d'un jeu vidéo c'est l'occasion d'aborder plein de choses différentes !",
                                },
                                {
                                    tag: "p",
                                    contents:
                                        "<em>Aucun prérequis nécessaire. Pas besoin d'être fort en maths ou en informatique, le but est d'apprendre et se détendre !</em>",
                                },
                            ],
                        },
                        {
                            tag: "div",
                            class: "practical-infos",
                            contents: [
                                {
                                    tag: "div",
                                    class: "info-item",
                                    contents: [
                                        { tag: "strong", contents: "Ça se passe où ?" },
                                        {
                                            tag: "span",
                                            contents:
                                                "Dans nos locaux,<br/><em>32 rue Simon Vialet, passage du Cheminou<br/>07240 Vernoux en Vivarais</em>",
                                        },
                                    ],
                                },
                                {
                                    tag: "div",
                                    class: "info-item",
                                    contents: [
                                        { tag: "strong", contents: "Pour qui ?" },
                                        {
                                            tag: "span",
                                            contents: "Tout le monde à partir de 12 ans.",
                                        },
                                    ],
                                },
                                {
                                    tag: "div",
                                    class: "info-item",
                                    contents: [
                                        {
                                            tag: "strong",
                                            contents: "Contact",
                                        },
                                        {
                                            tag: "span",
                                            contents: "04 75 78 08 72",
                                        },
                                        {
                                            tag: "a",
                                            href: "mailto:kuadrado-software@tutanota.com",
                                            contents: "kuadrado-software@tutanota.com",
                                        },
                                    ],
                                },
                            ],
                        },
                        {
                            tag: "ul",
                            class: "learning-themes",
                            contents: GAMEDEV_THEMES.map(li => {
                                return {
                                    tag: "li",
                                    class: "learning-theme " + li.class,
                                    contents: [
                                        { tag: "strong", class: "title", contents: li.title },
                                        {
                                            tag: "div",
                                            class: "details",
                                            contents: [
                                                li.comment && {
                                                    tag: "div",
                                                    class: "comment",
                                                    contents: li.comment,
                                                },
                                                {
                                                    tag: "ul",
                                                    contents: li.details.map(d => {
                                                        return {
                                                            tag: "li",
                                                            contents: d,
                                                        };
                                                    }),
                                                },
                                            ],
                                        },
                                    ],
                                };
                            }),
                        },
                        {
                            tag: "p",
                            class: "full-row",
                            contents: `<b>Une de ces choses vous intéresse mais pas spécialement le jeu vidéo ?</b>
                                <br>Pas de problème ! On peut se concentrer par exemple uniquement sur de la création 2D, ou de la création sonore, ou même uniquement des maths !
                                <br>L'orientation se fait en fonction des préférences de chacun.`,
                        },
                        {
                            tag: "div",
                            class: "infos-inscriptions full-row",
                            contents: [
                                {
                                    tag: "div",
                                    class: "groups",
                                    contents: [
                                        {
                                            tag: "h3",
                                            contents: "Groupes",
                                        },
                                        {
                                            tag: "p",
                                            contents: "Les groupes sont de 5 personnes maximum.",
                                        },
                                        {
                                            tag: "div",
                                            class: "table-wrapper",
                                            contents: [
                                                {
                                                    tag: "table",
                                                    contents: [
                                                        {
                                                            tag: "tr",
                                                            contents: [
                                                                { tag: "td", contents: "Mardi" },
                                                                {
                                                                    tag: "td",
                                                                    contents: "16h - 19h",
                                                                },
                                                            ],
                                                        },
                                                        {
                                                            tag: "tr",
                                                            contents: [
                                                                { tag: "td", contents: "Mercredi" },
                                                                {
                                                                    tag: "td",
                                                                    contents: "14h - 17h",
                                                                },
                                                            ],
                                                        },
                                                        {
                                                            tag: "tr",
                                                            contents: [
                                                                { tag: "td", contents: "Jeudi" },
                                                                {
                                                                    tag: "td",
                                                                    contents: "16h - 19h",
                                                                },
                                                            ],
                                                        },
                                                    ],
                                                },
                                            ],
                                        },
                                    ],
                                },
                                {
                                    tag: "div",
                                    class: "pricing",
                                    contents: [
                                        {
                                            tag: "h3",
                                            contents: "Inscription, fonctionnement et tarifs",
                                        },
                                        {
                                            tag: "p",
                                            contents: `Vous pouvez vous inscrire dans un des groupes pour un mois ou un trimestre.
                                        <br>Le matériel informatique est fourni sur place, mais vous pouvez amener votre propre ordinateur portable si vous le souhaitez.
                                        `,
                                        },
                                        {
                                            tag: "div",
                                            class: "table-wrapper",
                                            contents: [
                                                {
                                                    tag: "table",
                                                    contents: [
                                                        {
                                                            tag: "tr",
                                                            contents: [
                                                                {
                                                                    tag: "td",
                                                                    contents: "Abonnement 1 mois",
                                                                },
                                                                {
                                                                    tag: "td",
                                                                    contents: "(4 séances)",
                                                                },
                                                                { tag: "td", contents: "70€" },
                                                            ],
                                                        },
                                                        {
                                                            tag: "tr",
                                                            contents: [
                                                                {
                                                                    tag: "td",
                                                                    contents:
                                                                        "Abonnement 1 trimestre",
                                                                },
                                                                {
                                                                    tag: "td",
                                                                    contents: "(12 séances)",
                                                                },
                                                                { tag: "td", contents: "190€" },
                                                            ],
                                                        },
                                                    ],
                                                },
                                            ],
                                        },
                                    ],
                                },
                            ],
                        },
                    ],
                },
            ],
        };
    }
}

module.exports = GameStudioClub;
